==> route53-1.60.0-sources.jar: software/amazon/awscdk/services/route53/CfnRecordSetGroupProps.java <==
package software.amazon.awscdk.services.route53;

/**
 * Properties for defining a `AWS::Route53::RecordSetGroup`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-recordsetgroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.266Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.CfnRecordSetGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnRecordSetGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnRecordSetGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Route53::RecordSetGroup.Comment`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-recordsetgroup.html#cfn-route53-recordsetgroup-comment
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getComment() {
        return null;
    }

    /**
     * `AWS::Route53::RecordSetGroup.HostedZoneId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-recordsetgroup.html#cfn-route53-recordsetgroup-hostedzoneid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHostedZoneId() {
        return null;
    }

    /**
     * `AWS::Route53::RecordSetGroup.HostedZoneName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-recordsetgroup.html#cfn-route53-recordsetgroup-hostedzonename
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHostedZoneName() {
        return null;
    }

    /**
     * `AWS::Route53::RecordSetGroup.RecordSets`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-recordsetgroup.html#cfn-route53-recordsetgroup-recordsets
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getRecordSets() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnRecordSetGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRecordSetGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnRecordSetGroupProps> {
        private java.lang.String comment;
        private java.lang.String hostedZoneId;
        private java.lang.String hostedZoneName;
        private java.lang.Object recordSets;

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getComment}
         * @param comment `AWS::Route53::RecordSetGroup.Comment`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comment(java.lang.String comment) {
            this.comment = comment;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getHostedZoneId}
         * @param hostedZoneId `AWS::Route53::RecordSetGroup.HostedZoneId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hostedZoneId(java.lang.String hostedZoneId) {
            this.hostedZoneId = hostedZoneId;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getHostedZoneName}
         * @param hostedZoneName `AWS::Route53::RecordSetGroup.HostedZoneName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hostedZoneName(java.lang.String hostedZoneName) {
            this.hostedZoneName = hostedZoneName;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getRecordSets}
         * @param recordSets `AWS::Route53::RecordSetGroup.RecordSets`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recordSets(software.amazon.awscdk.core.IResolvable recordSets) {
            this.recordSets = recordSets;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getRecordSets}
         * @param recordSets `AWS::Route53::RecordSetGroup.RecordSets`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recordSets(java.util.List<java.lang.Object> recordSets) {
            this.recordSets = recordSets;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRecordSetGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnRecordSetGroupProps build() {
            return new Jsii$Proxy(comment, hostedZoneId, hostedZoneName, recordSets);
        }
    }

    /**
     * An implementation for {@link CfnRecordSetGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRecordSetGroupProps {
        private final java.lang.String comment;
        private final java.lang.String hostedZoneId;
        private final java.lang.String hostedZoneName;
        private final java.lang.Object recordSets;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.comment = this.jsiiGet("comment", java.lang.String.class);
            this.hostedZoneId = this.jsiiGet("hostedZoneId", java.lang.String.class);
            this.hostedZoneName = this.jsiiGet("hostedZoneName", java.lang.String.class);
            this.recordSets = this.jsiiGet("recordSets", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String comment, final java.lang.String hostedZoneId, final java.lang.String hostedZoneName, final java.lang.Object recordSets) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.comment = comment;
            this.hostedZoneId = hostedZoneId;
            this.hostedZoneName = hostedZoneName;
            this.recordSets = recordSets;
        }

        @Override
        public java.lang.String getComment() {
            return this.comment;
        }

        @Override
        public java.lang.String getHostedZoneId() {
            return this.hostedZoneId;
        }

        @Override
        public java.lang.String getHostedZoneName() {
            return this.hostedZoneName;
        }

        @Override
        public java.lang.Object getRecordSets() {
            return this.recordSets;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getComment() != null) {
                data.set("comment", om.valueToTree(this.getComment()));
            }
            if (this.getHostedZoneId() != null) {
                data.set("hostedZoneId", om.valueToTree(this.getHostedZoneId()));
            }
            if (this.getHostedZoneName() != null) {
                data.set("hostedZoneName", om.valueToTree(this.getHostedZoneName()));
            }
            if (this.getRecordSets() != null) {
                data.set("recordSets", om.valueToTree(this.getRecordSets()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-route53.CfnRecordSetGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRecordSetGroupProps.Jsii$Proxy that = (CfnRecordSetGroupProps.Jsii$Proxy) o;

            if (this.comment != null ? !this.comment.equals(that.comment) : that.comment != null) return false;
            if (this.hostedZoneId != null ? !this.hostedZoneId.equals(that.hostedZoneId) : that.hostedZoneId != null) return false;
            if (this.hostedZoneName != null ? !this.hostedZoneName.equals(that.hostedZoneName) : that.hostedZoneName != null) return false;
            return this.recordSets != null ? this.recordSets.equals(that.recordSets) : that.recordSets == null;
        }

        @Override
        public int hashCode() {
            int result = this.comment != null ? this.comment.hashCode() : 0;
            result = 31 * result + (this.hostedZoneId != null ? this.hostedZoneId.hashCode() : 0);
            result = 31 * result + (this.hostedZoneName != null ? this.hostedZoneName.hashCode() : 0);
            result = 31 * result + (this.recordSets != null ? this.recordSets.hashCode() : 0);
            return result;
        }
    }
}

==> route53-1.100.0-sources.jar: software/amazon/awscdk/services/route53/CfnRecordSetGroupProps.java <==
package software.amazon.awscdk.services.route53;

/**
 * Properties for defining a `AWS::Route53::RecordSetGroup`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:22.492Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.CfnRecordSetGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnRecordSetGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnRecordSetGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Route53::RecordSetGroup.Comment`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getComment() {
        return null;
    }

    /**
     * `AWS::Route53::RecordSetGroup.HostedZoneId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHostedZoneId() {
        return null;
    }

    /**
     * `AWS::Route53::RecordSetGroup.HostedZoneName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHostedZoneName() {
        return null;
    }

    /**
     * `AWS::Route53::RecordSetGroup.RecordSets`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getRecordSets() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnRecordSetGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRecordSetGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnRecordSetGroupProps> {
        private java.lang.String comment;
        private java.lang.String hostedZoneId;
        private java.lang.String hostedZoneName;
        private java.lang.Object recordSets;

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getComment}
         * @param comment `AWS::Route53::RecordSetGroup.Comment`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comment(java.lang.String comment) {
            this.comment = comment;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getHostedZoneId}
         * @param hostedZoneId `AWS::Route53::RecordSetGroup.HostedZoneId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hostedZoneId(java.lang.String hostedZoneId) {
            this.hostedZoneId = hostedZoneId;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getHostedZoneName}
         * @param hostedZoneName `AWS::Route53::RecordSetGroup.HostedZoneName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hostedZoneName(java.lang.String hostedZoneName) {
            this.hostedZoneName = hostedZoneName;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getRecordSets}
         * @param recordSets `AWS::Route53::RecordSetGroup.RecordSets`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recordSets(software.amazon.awscdk.core.IResolvable recordSets) {
            this.recordSets = recordSets;
            return this;
        }

        /**
         * Sets the value of {@link CfnRecordSetGroupProps#getRecordSets}
         * @param recordSets `AWS::Route53::RecordSetGroup.RecordSets`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recordSets(java.util.List<? extends java.lang.Object> recordSets) {
            this.recordSets = recordSets;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRecordSetGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnRecordSetGroupProps build() {
            return new Jsii$Proxy(comment, hostedZoneId, hostedZoneName, recordSets);
        }
    }

    /**
     * An implementation for {@link CfnRecordSetGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRecordSetGroupProps {
        private final java.lang.String comment;
        private final java.lang.String hostedZoneId;
        private final java.lang.String hostedZoneName;
        private final java.lang.Object recordSets;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.comment = software.amazon.jsii.Kernel.get(this, "comment", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.hostedZoneId = software.amazon.jsii.Kernel.get(this, "hostedZoneId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.hostedZoneName = software.amazon.jsii.Kernel.get(this, "hostedZoneName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.recordSets = software.amazon.jsii.Kernel.get(this, "recordSets", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String comment, final java.lang.String hostedZoneId, final java.lang.String hostedZoneName, final java.lang.Object recordSets) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.comment = comment;
            this.hostedZoneId = hostedZoneId;
            this.hostedZoneName = hostedZoneName;
            this.recordSets = recordSets;
        }

        @Override
        public final java.lang.String getComment() {
            return this.comment;
        }

        @Override
        public final java.lang.String getHostedZoneId() {
            return this.hostedZoneId;
        }

        @Override
        public final java.lang.String getHostedZoneName() {
            return this.hostedZoneName;
        }

        @Override
        public final java.lang.Object getRecordSets() {
            return this.recordSets;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getComment() != null) {
                data.set("comment", om.valueToTree(this.getComment()));
            }
            if (this.getHostedZoneId() != null) {
                data.set("hostedZoneId", om.valueToTree(this.getHostedZoneId()));
            }
            if (this.getHostedZoneName() != null) {
                data.set("hostedZoneName", om.valueToTree(this.getHostedZoneName()));
            }
            if (this.getRecordSets() != null) {
                data.set("recordSets", om.valueToTree(this.getRecordSets()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-route53.CfnRecordSetGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRecordSetGroupProps.Jsii$Proxy that = (CfnRecordSetGroupProps.Jsii$Proxy) o;

            if (this.comment != null ? !this.comment.equals(that.comment) : that.comment != null) return false;
            if (this.hostedZoneId != null ? !this.hostedZoneId.equals(that.hostedZoneId) : that.hostedZoneId != null) return false;
            if (this.hostedZoneName != null ? !this.hostedZoneName.equals(that.hostedZoneName) : that.hostedZoneName != null) return false;
            return this.recordSets != null ? this.recordSets.equals(that.recordSets) : that.recordSets == null;
        }

        @Override
        public final int hashCode() {
            int result = this.comment != null ? this.comment.hashCode() : 0;
            result = 31 * result + (this.hostedZoneId != null ? this.hostedZoneId.hashCode() : 0);
            result = 31 * result + (this.hostedZoneName != null ? this.hostedZoneName.hashCode() : 0);
            result = 31 * result + (this.recordSets != null ? this.recordSets.hashCode() : 0);
            return result;
        }
    }
}
